@@ -11,7 +11,7 @@ use warnings;
 #my $VERSION="0.1";
 
 #For CVS , use following line
-our $VERSION=sprintf("%d.%04d", q$Revision: 2006.0615 $ =~ /(\d+)\.(\d+)/);
+our $VERSION=sprintf("%d.%04d", q$Revision: 2006.0626 $ =~ /(\d+)\.(\d+)/);
 
 BEGIN {
 
@@ -1948,7 +1948,7 @@ sub WWW::YouTube::HTML::video_flagger_form
       ' </select>' ."\n".
       ' <input type="submit" name="submit" value="S"' ."\n".
       '  onMouseOver=\'window.status="'.
-          '[P](Pornography or Obsenity) '.
+          '[P](Pornography or Obscenity) '.
           '[I](Illegal Acts) '.
           '[G](Graphic Violence) '.
           '[R](Racially or Ethnically Offensive Content)'.
